//  Copyright 2007 FoxyTunes 
//  All Rights Reserved

if (typeof(ExtraUtils) == "undefined") {
    var ExtraUtils = function() { };
}

if (typeof(ExtraUtils['1.0']) == "undefined") {
    ExtraUtils['1.0'] = function() { };

    ExtraUtils['1.0'].prototype = {
        setLocalePath: function(localePath, localeFallbackPath) {
            this.localePath = localePath;
            this.localeFallbackPath = localeFallbackPath;
        },

        setPrefBranch: function(prefBranch) {
            this.prefService = Components.classes["@mozilla.org/preferences-service;1"]
                            .getService(Components.interfaces.nsIPrefService);
            this.pref = this.prefService.getBranch(prefBranch + "."); 
        },

        getLocaleString: function(strName, formattingValues) {
         try {
            var stringBundleService = Components.classes['@mozilla.org/intl/stringbundle;1'].
                                        createInstance(Components.interfaces.nsIStringBundleService);
            if (this.localePath) {
                var strbundle = stringBundleService.createBundle(this.localePath);
            }
            if (this.localeFallbackPath) {
                var strbundleFallback = stringBundleService.createBundle(this.localeFallbackPath);
            }
            var val = '';

            if (formattingValues === undefined) {
                try {
    		        val = strbundle.GetStringFromName(strName);
                } catch(e) {
        	        val = strbundleFallback.GetStringFromName(strName);
                }
            } else {
                try {
    	    	    val = strbundle.formatStringFromName(strName, formattingValues, formattingValues.length);
                } catch(e) {
        			val = strbundleFallback.formatStringFromName(strName, formattingValues, formattingValues.length);
                }
            }
         } catch (err) {
            dump("Couldn't get string: " + strName + "\n");
         }   
        return val;
       },

       writeSingleCharPreference: function(key, value, prefBranch) {
           if (typeof(prefBranch) == 'undefined') {
                prefBranch = this.pref;
           } else {
                prefBranch = this.prefService.getBranch(prefBranch + "."); 
           }
           try {
             prefBranch.setCharPref(key, value);
           } catch (err) {
             dump("\nSetting preference for key " + key + " (" + value + ") failed: " + err + "\n");
           }
           try {
              this.prefService.savePrefFile(null);
           } catch (err) {
                dump("\nSaving preferences failed: " + err + "\n");
           }
        },

        readSingleCharPreference: function(key, defaultVal, prefBranch) {
           if (typeof(prefBranch) == 'undefined') {
                prefBranch = this.pref;
           } else {
                prefBranch = this.prefService.getBranch(prefBranch + "."); 
           }

           var val;
           try {
             val = prefBranch.getCharPref(key);
           } catch (err) {
             val = defaultVal; 
           }
           return val;
        },

        writeSingleBoolPreference: function(key, value, prefBranch) {
           if (typeof(prefBranch) == 'undefined') {
                prefBranch = this.pref;
           } else {
                prefBranch = this.prefService.getBranch(prefBranch + "."); 
           }

           try {
             prefBranch.setBoolPref(key, value);
           } catch (err) {
             dump("\nSetting preference for key " + key + " (" + value + ") failed: " + err + "\n");
           }
           try {
              this.prefService.savePrefFile(null);
           } catch (err) {
                dump("\nSaving preferences failed: " + err + "\n");
           }
        },

        readSingleBoolPreference: function(key, defaultVal, prefBranch) {
           if (typeof(prefBranch) == 'undefined') {
                prefBranch = this.pref;
           } else {
                prefBranch = this.prefService.getBranch(prefBranch + "."); 
           }

           var val;
           try {
             val = prefBranch.getBoolPref(key);
           } catch (err) {
             val = defaultVal; 
           }
           return val;
        },

        gotoURL: function(url) {
            var newTab = gBrowser.addTab(url);
            gBrowser.selectedTab = newTab;
        },
   
        foxytunesIsInstalled: function() {
            var foxytunesService = null;
            try {
                // The following code accesses internal FoxyTunes objects. 
                // Such access is currently allowed only to approved applications. 
                // If you are interested in this functionality please contact us at info@foxytunes.com
                foxytunesService = Components.classes['@foxytunes.org/FoxyTunesEngine/FoxyTunesService;1'].
                                 getService(Components.interfaces.IFoxyTunesService);
            } catch(e) {};
            return (foxytunesService ? true : false);
        },

        getExtensionVersion: function(guid) {
            var value = null;
            try {
               var RDFService = Components.classes["@mozilla.org/rdf/rdf-service;1"]
                     .getService(Components.interfaces.nsIRDFService);
               var extensionDS= Components.classes["@mozilla.org/extensions/manager;1"]
            	      .getService(Components.interfaces.nsIExtensionManager).datasource;
               var root = RDFService
                     .GetResource("urn:mozilla:item:" + guid);
               var itemArc = RDFService
                     .GetResource("http://www.mozilla.org/2004/em-rdf#version");
   
               var target = extensionDS.GetTarget(root, itemArc, true);
               value = target.QueryInterface(Components.interfaces.nsIRDFLiteral).Value;
            } catch(e) {}
            return value;
        },
        
        isExtrasSupported: function() {
            return this.readSingleBoolPreference('supported', false, 'foxytunes.extras');
        },

        getPlatform: function() {
        	var platform = navigator.platform.toLowerCase();
    	
	        if (platform.indexOf('linux') != -1) {
        		return 'linux';
        	}       

        	if (platform.indexOf('mac') != -1) {
        		return 'mac';
        	}

        	return 'windows';
        }
    }
}
